==> neural_compressor-2.1.tar.gz: neural_compressor-2.1/neural_compressor/data/transforms/coco_transform.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2021 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Copyright 2017 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

from neural_compressor.utils import logger
from neural_compressor.data.transforms import transform_registry, BaseTransform

# BELOW IS TO BE DEPRECATED!
@transform_registry(transform_type="ParseDecodeCoco", \
                    process="preprocess", framework="tensorflow")
class ParseDecodeCocoTransform(BaseTransform):    # pragma: no cover 
    """Coco decoding will be performed automatically from Neural Compressor v1.4.
    """
    def __call__(self, sample):
        """Convert `ParseDecodeCocoTransform` feature."""
        logger.warning("This transform is going to be deprecated, " \
            "coco decoding will be performed automatically from Neural Compressor v1.4.")
        return sample

==> neural_compressor-2.3.tar.gz: neural_compressor-2.3/neural_compressor/data/transforms/coco_transform.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2021 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Copyright 2017 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

from neural_compressor.data.transforms import BaseTransform, transform_registry
from neural_compressor.utils import logger


# BELOW IS TO BE DEPRECATED!
@transform_registry(transform_type="ParseDecodeCoco", process="preprocess", framework="tensorflow")
class ParseDecodeCocoTransform(BaseTransform):  # pragma: no cover
    """Coco decoding will be performed automatically from Neural Compressor v1.4."""

    def __call__(self, sample):
        """Convert `ParseDecodeCocoTransform` feature."""
        logger.warning(
            "This transform is going to be deprecated, "
            "coco decoding will be performed automatically from Neural Compressor v1.4."
        )
        return sample
